Index: /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.cpp	(revision 64690)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.cpp	(revision 64691)
@@ -52,19 +52,19 @@
 public:
 
-    /** Constructs item with specified @a number, @a type and @a pParent. */
-    ModelItem(int number, ApplianceModelItemType type, ModelItem *pParent = NULL);
+    /** Constructs item with specified @a iNumber, @a enmType and @a pParentItem. */
+    ModelItem(int iNumber, ApplianceModelItemType enmType, ModelItem *pParentItem = 0);
     /** Destructs item. */
     virtual ~ModelItem();
 
     /** Returns the item type. */
-    ApplianceModelItemType type() const { return m_type; }
+    ApplianceModelItemType type() const { return m_enmType; }
 
     /** Returns the parent of the item. */
     ModelItem *parent() const { return m_pParentItem; }
 
-    /** Appends the passed @a pChild to the item's list of children. */
-    void appendChild(ModelItem *pChild);
-    /** Returns the child specified by the @a row. */
-    ModelItem *child(int row) const;
+    /** Appends the passed @a pChildItem to the item's list of children. */
+    void appendChild(ModelItem *pChildItem);
+    /** Returns the child specified by the @a iRow. */
+    ModelItem *child(int iRow) const;
 
     /** Returns the row of the item in the parent. */
@@ -76,16 +76,16 @@
     int columnCount() const { return 3; }
 
-    /** Returns the item flags for the given @a column. */
-    virtual Qt::ItemFlags itemFlags(int /* column */) const { return 0; }
-
-    /** Defines the @a role data for the item at @a column to @a value. */
-    virtual bool setData(int /* column */, const QVariant & /* value */, int /* role */) { return false; }
-    /** Returns the data stored under the given @a role for the item referred to by the @a column. */
-    virtual QVariant data(int /* column */, int /* role */) const { return QVariant(); }
+    /** Returns the item flags for the given @a iColumn. */
+    virtual Qt::ItemFlags itemFlags(int /* iColumn */) const { return 0; }
+
+    /** Defines the @a iRole data for the item at @a iColumn to @a value. */
+    virtual bool setData(int /* iColumn */, const QVariant & /* value */, int /* iRole */) { return false; }
+    /** Returns the data stored under the given @a iRole for the item referred to by the @a iColumn. */
+    virtual QVariant data(int /* iColumn */, int /* iRole */) const { return QVariant(); }
 
     /** Returns the widget used to edit the item specified by @a idx for editing.
       * @param  pParent      Brings the parent to be assigned for newly created editor.
       * @param  styleOption  Bring the style option set for the newly created editor. */
-    virtual QWidget *createEditor(QWidget * /* pParent */, const QStyleOptionViewItem & /* styleOption */, const QModelIndex & /* idx */) const { return NULL; }
+    virtual QWidget *createEditor(QWidget * /* pParent */, const QStyleOptionViewItem & /* styleOption */, const QModelIndex & /* idx */) const { return 0; }
 
     /** Defines the contents of the given @a pEditor to the data for the item at the given @a idx. */
@@ -98,12 +98,12 @@
 
     /** Cache currently stored values, such as @a finalStates, @a finalValues and @a finalExtraValues. */
-    virtual void putBack(QVector<BOOL>& finalStates, QVector<QString>& finalValues, QVector<QString>& finalExtraValues);
+    virtual void putBack(QVector<BOOL> &finalStates, QVector<QString> &finalValues, QVector<QString> &finalExtraValues);
 
 protected:
 
     /** Holds the item number. */
-    int                     m_number;
+    int                     m_iNumber;
     /** Holds the item type. */
-    ApplianceModelItemType  m_type;
+    ApplianceModelItemType  m_enmType;
 
     /** Holds the parent item reference. */
@@ -119,18 +119,18 @@
 public:
 
-    /** Constructs item passing @a number and @a pParent to the base-class.
-      * @param  aDesc  Brings the Virtual System Description. */
-    VirtualSystemItem(int number, CVirtualSystemDescription aDesc, ModelItem *pParent);
-
-    /** Returns the data stored under the given @a role for the item referred to by the @a column. */
-    virtual QVariant data(int column, int role) const;
+    /** Constructs item passing @a iNumber and @a pParentItem to the base-class.
+      * @param  enmDescription  Brings the Virtual System Description. */
+    VirtualSystemItem(int iNumber, CVirtualSystemDescription enmDescription, ModelItem *pParentItem);
+
+    /** Returns the data stored under the given @a iRole for the item referred to by the @a iColumn. */
+    virtual QVariant data(int iColumn, int iRole) const;
 
     /** Cache currently stored values, such as @a finalStates, @a finalValues and @a finalExtraValues. */
-    virtual void putBack(QVector<BOOL>& finalStates, QVector<QString>& finalValues, QVector<QString>& finalExtraValues);
+    virtual void putBack(QVector<BOOL> &finalStates, QVector<QString> &finalValues, QVector<QString> &finalExtraValues);
 
 private:
 
     /** Holds the Virtual System Description. */
-    CVirtualSystemDescription m_desc;
+    CVirtualSystemDescription m_enmDescription;
 };
 
@@ -150,25 +150,25 @@
 public:
 
-    /** Constructs item passing @a number and @a pParent to the base-class.
-      * @param  type                 Brings the Virtual System Description type.
+    /** Constructs item passing @a iNumber and @a pParentItem to the base-class.
+      * @param  enmType              Brings the Virtual System Description type.
       * @param  strRef               Brings something totally useless.
       * @param  strOrigValue         Brings the original value.
       * @param  strConfigValue       Brings the configuration value.
       * @param  strExtraConfigValue  Brings the extra configuration value. */
-    HardwareItem(int number,
-                 KVirtualSystemDescriptionType type,
+    HardwareItem(int iNumber,
+                 KVirtualSystemDescriptionType enmType,
                  const QString &strRef,
                  const QString &strOrigValue,
                  const QString &strConfigValue,
                  const QString &strExtraConfigValue,
-                 ModelItem *pParent);
-
-    /** Returns the item flags for the given @a column. */
-    virtual Qt::ItemFlags itemFlags(int column) const;
-
-    /** Defines the @a role data for the item at @a column to @a value. */
-    virtual bool setData(int column, const QVariant &value, int role);
-    /** Returns the data stored under the given @a role for the item referred to by the @a column. */
-    virtual QVariant data(int column, int role) const;
+                 ModelItem *pParentItem);
+
+    /** Returns the item flags for the given @a iColumn. */
+    virtual Qt::ItemFlags itemFlags(int iColumn) const;
+
+    /** Defines the @a iRole data for the item at @a iColumn to @a value. */
+    virtual bool setData(int iColumn, const QVariant &value, int iRole);
+    /** Returns the data stored under the given @a iRole for the item referred to by the @a iColumn. */
+    virtual QVariant data(int iColumn, int iRole) const;
 
     /** Returns the widget used to edit the item specified by @a idx for editing.
@@ -186,10 +186,10 @@
 
     /** Cache currently stored values, such as @a finalStates, @a finalValues and @a finalExtraValues. */
-    virtual void putBack(QVector<BOOL>& finalStates, QVector<QString>& finalValues, QVector<QString>& finalExtraValues);
+    virtual void putBack(QVector<BOOL> &finalStates, QVector<QString> &finalValues, QVector<QString> &finalExtraValues);
 
 private:
 
     /** Holds the Virtual System description type. */
-    KVirtualSystemDescriptionType m_type;
+    KVirtualSystemDescriptionType m_enmType;
     /** Holds something totally useless. */
     QString                       m_strRef;
@@ -213,13 +213,10 @@
 *********************************************************************************************************************************/
 
-/* This & the following derived classes represent the data items of a Virtual
-   System. All access/manipulation is done with the help of virtual functions
-   to keep the interface clean. ModelItem is able to handle tree structures
-   with a parent & several children's. */
-ModelItem::ModelItem(int number, ApplianceModelItemType type, ModelItem *pParent /* = NULL */)
-  : m_number(number)
-  , m_type(type)
-  , m_pParentItem(pParent)
-{}
+ModelItem::ModelItem(int iNumber, ApplianceModelItemType enmType, ModelItem *pParentItem /* = 0 */)
+    : m_iNumber(iNumber)
+    , m_enmType(enmType)
+    , m_pParentItem(pParentItem)
+{
+}
 
 ModelItem::~ModelItem()
@@ -228,13 +225,13 @@
 }
 
-void ModelItem::appendChild(ModelItem *pChild)
-{
-    AssertPtr(pChild);
-    m_childItems << pChild;
-}
-
-ModelItem *ModelItem::child(int row) const
-{
-    return m_childItems.value(row);
+void ModelItem::appendChild(ModelItem *pChildItem)
+{
+    AssertPtr(pChildItem);
+    m_childItems << pChildItem;
+}
+
+ModelItem *ModelItem::child(int iRow) const
+{
+    return m_childItems.value(iRow);
 }
 
@@ -252,5 +249,5 @@
 }
 
-void ModelItem::putBack(QVector<BOOL>& finalStates, QVector<QString>& finalValues, QVector<QString>& finalExtraValues)
+void ModelItem::putBack(QVector<BOOL> &finalStates, QVector<QString> &finalValues, QVector<QString> &finalExtraValues)
 {
     for (int i = 0; i < childCount(); ++i)
@@ -263,29 +260,30 @@
 *********************************************************************************************************************************/
 
-VirtualSystemItem::VirtualSystemItem(int number, CVirtualSystemDescription aDesc, ModelItem *pParent)
-  : ModelItem(number, ApplianceModelItemType_VirtualSystem, pParent)
-  , m_desc(aDesc)
-{}
-
-QVariant VirtualSystemItem::data(int column, int role) const
-{
-    QVariant v;
-    if (column == ApplianceViewSection_Description &&
-        role == Qt::DisplayRole)
-        v = UIApplianceEditorWidget::tr("Virtual System %1").arg(m_number + 1);
-    return v;
-}
-
-void VirtualSystemItem::putBack(QVector<BOOL>& finalStates, QVector<QString>& finalValues, QVector<QString>& finalExtraValues)
+VirtualSystemItem::VirtualSystemItem(int iNumber, CVirtualSystemDescription enmDescription, ModelItem *pParentItem)
+    : ModelItem(iNumber, ApplianceModelItemType_VirtualSystem, pParentItem)
+    , m_enmDescription(enmDescription)
+{
+}
+
+QVariant VirtualSystemItem::data(int iColumn, int iRole) const
+{
+    QVariant value;
+    if (iColumn == ApplianceViewSection_Description &&
+        iRole == Qt::DisplayRole)
+        value = UIApplianceEditorWidget::tr("Virtual System %1").arg(m_iNumber + 1);
+    return value;
+}
+
+void VirtualSystemItem::putBack(QVector<BOOL> &finalStates, QVector<QString> &finalValues, QVector<QString> &finalExtraValues)
 {
     /* Resize the vectors */
-    unsigned long count = m_desc.GetCount();
-    finalStates.resize(count);
-    finalValues.resize(count);
-    finalExtraValues.resize(count);
+    unsigned long iCount = m_enmDescription.GetCount();
+    finalStates.resize(iCount);
+    finalValues.resize(iCount);
+    finalExtraValues.resize(iCount);
     /* Recursively fill the vectors */
     ModelItem::putBack(finalStates, finalValues, finalExtraValues);
     /* Set all final values at once */
-    m_desc.SetFinalValues(finalStates, finalValues, finalExtraValues);
+    m_enmDescription.SetFinalValues(finalStates, finalValues, finalExtraValues);
 }
 
@@ -295,70 +293,70 @@
 *********************************************************************************************************************************/
 
-HardwareItem::HardwareItem(int number,
-                           KVirtualSystemDescriptionType type,
+HardwareItem::HardwareItem(int iNumber,
+                           KVirtualSystemDescriptionType enmType,
                            const QString &strRef,
                            const QString &aOrigValue,
                            const QString &strConfigValue,
                            const QString &strExtraConfigValue,
-                           ModelItem *pParent)
-  : ModelItem(number, ApplianceModelItemType_Hardware, pParent)
-  , m_type(type)
-  , m_strRef(strRef)
-  , m_strOrigValue(aOrigValue)
-  , m_strConfigValue(strConfigValue)
-  , m_strConfigDefaultValue(strConfigValue)
-  , m_strExtraConfigValue(strExtraConfigValue)
-  , m_checkState(Qt::Checked)
-  , m_fModified(false)
-{
-}
-
-Qt::ItemFlags HardwareItem::itemFlags(int column) const
-{
-    Qt::ItemFlags flags = 0;
-    if (column == ApplianceViewSection_ConfigValue)
+                           ModelItem *pParentItem)
+    : ModelItem(iNumber, ApplianceModelItemType_Hardware, pParentItem)
+    , m_enmType(enmType)
+    , m_strRef(strRef)
+    , m_strOrigValue(aOrigValue)
+    , m_strConfigValue(strConfigValue)
+    , m_strConfigDefaultValue(strConfigValue)
+    , m_strExtraConfigValue(strExtraConfigValue)
+    , m_checkState(Qt::Checked)
+    , m_fModified(false)
+{
+}
+
+Qt::ItemFlags HardwareItem::itemFlags(int iColumn) const
+{
+    Qt::ItemFlags enmFlags = 0;
+    if (iColumn == ApplianceViewSection_ConfigValue)
     {
         /* Some items are checkable */
-        if (m_type == KVirtualSystemDescriptionType_Floppy ||
-            m_type == KVirtualSystemDescriptionType_CDROM ||
-            m_type == KVirtualSystemDescriptionType_USBController ||
-            m_type == KVirtualSystemDescriptionType_SoundCard ||
-            m_type == KVirtualSystemDescriptionType_NetworkAdapter)
-            flags |= Qt::ItemIsUserCheckable;
+        if (m_enmType == KVirtualSystemDescriptionType_Floppy ||
+            m_enmType == KVirtualSystemDescriptionType_CDROM ||
+            m_enmType == KVirtualSystemDescriptionType_USBController ||
+            m_enmType == KVirtualSystemDescriptionType_SoundCard ||
+            m_enmType == KVirtualSystemDescriptionType_NetworkAdapter)
+            enmFlags |= Qt::ItemIsUserCheckable;
         /* Some items are editable */
-        if ((m_type == KVirtualSystemDescriptionType_Name ||
-             m_type == KVirtualSystemDescriptionType_Product ||
-             m_type == KVirtualSystemDescriptionType_ProductUrl ||
-             m_type == KVirtualSystemDescriptionType_Vendor ||
-             m_type == KVirtualSystemDescriptionType_VendorUrl ||
-             m_type == KVirtualSystemDescriptionType_Version ||
-             m_type == KVirtualSystemDescriptionType_Description ||
-             m_type == KVirtualSystemDescriptionType_License ||
-             m_type == KVirtualSystemDescriptionType_OS ||
-             m_type == KVirtualSystemDescriptionType_CPU ||
-             m_type == KVirtualSystemDescriptionType_Memory ||
-             m_type == KVirtualSystemDescriptionType_SoundCard ||
-             m_type == KVirtualSystemDescriptionType_NetworkAdapter ||
-             m_type == KVirtualSystemDescriptionType_HardDiskControllerIDE ||
-             m_type == KVirtualSystemDescriptionType_HardDiskImage) &&
+        if ((m_enmType == KVirtualSystemDescriptionType_Name ||
+             m_enmType == KVirtualSystemDescriptionType_Product ||
+             m_enmType == KVirtualSystemDescriptionType_ProductUrl ||
+             m_enmType == KVirtualSystemDescriptionType_Vendor ||
+             m_enmType == KVirtualSystemDescriptionType_VendorUrl ||
+             m_enmType == KVirtualSystemDescriptionType_Version ||
+             m_enmType == KVirtualSystemDescriptionType_Description ||
+             m_enmType == KVirtualSystemDescriptionType_License ||
+             m_enmType == KVirtualSystemDescriptionType_OS ||
+             m_enmType == KVirtualSystemDescriptionType_CPU ||
+             m_enmType == KVirtualSystemDescriptionType_Memory ||
+             m_enmType == KVirtualSystemDescriptionType_SoundCard ||
+             m_enmType == KVirtualSystemDescriptionType_NetworkAdapter ||
+             m_enmType == KVirtualSystemDescriptionType_HardDiskControllerIDE ||
+             m_enmType == KVirtualSystemDescriptionType_HardDiskImage) &&
             m_checkState == Qt::Checked) /* Item has to be enabled */
-            flags |= Qt::ItemIsEditable;
+            enmFlags |= Qt::ItemIsEditable;
     }
-    return flags;
-}
-
-bool HardwareItem::setData(int column, const QVariant &value, int role)
+    return enmFlags;
+}
+
+bool HardwareItem::setData(int iColumn, const QVariant &value, int iRole)
 {
     bool fDone = false;
-    switch (role)
+    switch (iRole)
     {
         case Qt::CheckStateRole:
         {
-            if (column == ApplianceViewSection_ConfigValue &&
-                (m_type == KVirtualSystemDescriptionType_Floppy ||
-                 m_type == KVirtualSystemDescriptionType_CDROM ||
-                 m_type == KVirtualSystemDescriptionType_USBController ||
-                 m_type == KVirtualSystemDescriptionType_SoundCard ||
-                 m_type == KVirtualSystemDescriptionType_NetworkAdapter))
+            if (iColumn == ApplianceViewSection_ConfigValue &&
+                (m_enmType == KVirtualSystemDescriptionType_Floppy ||
+                 m_enmType == KVirtualSystemDescriptionType_CDROM ||
+                 m_enmType == KVirtualSystemDescriptionType_USBController ||
+                 m_enmType == KVirtualSystemDescriptionType_SoundCard ||
+                 m_enmType == KVirtualSystemDescriptionType_NetworkAdapter))
             {
                 m_checkState = static_cast<Qt::CheckState>(value.toInt());
@@ -369,7 +367,7 @@
         case Qt::EditRole:
         {
-            if (column == ApplianceViewSection_OriginalValue)
+            if (iColumn == ApplianceViewSection_OriginalValue)
                 m_strOrigValue = value.toString();
-            else if (column == ApplianceViewSection_ConfigValue)
+            else if (iColumn == ApplianceViewSection_ConfigValue)
                 m_strConfigValue = value.toString();
             break;
@@ -380,52 +378,52 @@
 }
 
-QVariant HardwareItem::data(int column, int role) const
-{
-    QVariant v;
-    switch (role)
+QVariant HardwareItem::data(int iColumn, int iRole) const
+{
+    QVariant value;
+    switch (iRole)
     {
         case Qt::EditRole:
         {
-            if (column == ApplianceViewSection_OriginalValue)
-                v = m_strOrigValue;
-            else if (column == ApplianceViewSection_ConfigValue)
-                v = m_strConfigValue;
+            if (iColumn == ApplianceViewSection_OriginalValue)
+                value = m_strOrigValue;
+            else if (iColumn == ApplianceViewSection_ConfigValue)
+                value = m_strConfigValue;
             break;
         }
         case Qt::DisplayRole:
         {
-            if (column == ApplianceViewSection_Description)
-            {
-                switch (m_type)
+            if (iColumn == ApplianceViewSection_Description)
+            {
+                switch (m_enmType)
                 {
-                    case KVirtualSystemDescriptionType_Name:                   v = UIApplianceEditorWidget::tr("Name"); break;
-                    case KVirtualSystemDescriptionType_Product:                v = UIApplianceEditorWidget::tr("Product"); break;
-                    case KVirtualSystemDescriptionType_ProductUrl:             v = UIApplianceEditorWidget::tr("Product-URL"); break;
-                    case KVirtualSystemDescriptionType_Vendor:                 v = UIApplianceEditorWidget::tr("Vendor"); break;
-                    case KVirtualSystemDescriptionType_VendorUrl:              v = UIApplianceEditorWidget::tr("Vendor-URL"); break;
-                    case KVirtualSystemDescriptionType_Version:                v = UIApplianceEditorWidget::tr("Version"); break;
-                    case KVirtualSystemDescriptionType_Description:            v = UIApplianceEditorWidget::tr("Description"); break;
-                    case KVirtualSystemDescriptionType_License:                v = UIApplianceEditorWidget::tr("License"); break;
-                    case KVirtualSystemDescriptionType_OS:                     v = UIApplianceEditorWidget::tr("Guest OS Type"); break;
-                    case KVirtualSystemDescriptionType_CPU:                    v = UIApplianceEditorWidget::tr("CPU"); break;
-                    case KVirtualSystemDescriptionType_Memory:                 v = UIApplianceEditorWidget::tr("RAM"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerIDE:  v = UIApplianceEditorWidget::tr("Storage Controller (IDE)"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerSATA: v = UIApplianceEditorWidget::tr("Storage Controller (SATA)"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerSCSI: v = UIApplianceEditorWidget::tr("Storage Controller (SCSI)"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerSAS:  v = UIApplianceEditorWidget::tr("Storage Controller (SAS)"); break;
-                    case KVirtualSystemDescriptionType_CDROM:                  v = UIApplianceEditorWidget::tr("DVD"); break;
-                    case KVirtualSystemDescriptionType_Floppy:                 v = UIApplianceEditorWidget::tr("Floppy"); break;
-                    case KVirtualSystemDescriptionType_NetworkAdapter:         v = UIApplianceEditorWidget::tr("Network Adapter"); break;
-                    case KVirtualSystemDescriptionType_USBController:          v = UIApplianceEditorWidget::tr("USB Controller"); break;
-                    case KVirtualSystemDescriptionType_SoundCard:              v = UIApplianceEditorWidget::tr("Sound Card"); break;
-                    case KVirtualSystemDescriptionType_HardDiskImage:          v = UIApplianceEditorWidget::tr("Virtual Disk Image"); break;
-                    default:                                                   v = UIApplianceEditorWidget::tr("Unknown Hardware Item"); break;
+                    case KVirtualSystemDescriptionType_Name:                   value = UIApplianceEditorWidget::tr("Name"); break;
+                    case KVirtualSystemDescriptionType_Product:                value = UIApplianceEditorWidget::tr("Product"); break;
+                    case KVirtualSystemDescriptionType_ProductUrl:             value = UIApplianceEditorWidget::tr("Product-URL"); break;
+                    case KVirtualSystemDescriptionType_Vendor:                 value = UIApplianceEditorWidget::tr("Vendor"); break;
+                    case KVirtualSystemDescriptionType_VendorUrl:              value = UIApplianceEditorWidget::tr("Vendor-URL"); break;
+                    case KVirtualSystemDescriptionType_Version:                value = UIApplianceEditorWidget::tr("Version"); break;
+                    case KVirtualSystemDescriptionType_Description:            value = UIApplianceEditorWidget::tr("Description"); break;
+                    case KVirtualSystemDescriptionType_License:                value = UIApplianceEditorWidget::tr("License"); break;
+                    case KVirtualSystemDescriptionType_OS:                     value = UIApplianceEditorWidget::tr("Guest OS Type"); break;
+                    case KVirtualSystemDescriptionType_CPU:                    value = UIApplianceEditorWidget::tr("CPU"); break;
+                    case KVirtualSystemDescriptionType_Memory:                 value = UIApplianceEditorWidget::tr("RAM"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerIDE:  value = UIApplianceEditorWidget::tr("Storage Controller (IDE)"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerSATA: value = UIApplianceEditorWidget::tr("Storage Controller (SATA)"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerSCSI: value = UIApplianceEditorWidget::tr("Storage Controller (SCSI)"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerSAS:  value = UIApplianceEditorWidget::tr("Storage Controller (SAS)"); break;
+                    case KVirtualSystemDescriptionType_CDROM:                  value = UIApplianceEditorWidget::tr("DVD"); break;
+                    case KVirtualSystemDescriptionType_Floppy:                 value = UIApplianceEditorWidget::tr("Floppy"); break;
+                    case KVirtualSystemDescriptionType_NetworkAdapter:         value = UIApplianceEditorWidget::tr("Network Adapter"); break;
+                    case KVirtualSystemDescriptionType_USBController:          value = UIApplianceEditorWidget::tr("USB Controller"); break;
+                    case KVirtualSystemDescriptionType_SoundCard:              value = UIApplianceEditorWidget::tr("Sound Card"); break;
+                    case KVirtualSystemDescriptionType_HardDiskImage:          value = UIApplianceEditorWidget::tr("Virtual Disk Image"); break;
+                    default:                                                   value = UIApplianceEditorWidget::tr("Unknown Hardware Item"); break;
                 }
             }
-            else if (column == ApplianceViewSection_OriginalValue)
-                v = m_strOrigValue;
-            else if (column == ApplianceViewSection_ConfigValue)
-            {
-                switch (m_type)
+            else if (iColumn == ApplianceViewSection_OriginalValue)
+                value = m_strOrigValue;
+            else if (iColumn == ApplianceViewSection_ConfigValue)
+            {
+                switch (m_enmType)
                 {
                     case KVirtualSystemDescriptionType_Description:
@@ -434,15 +432,15 @@
                         /* Shorten the big text if there is more than
                          * one line */
-                        QString tmp(m_strConfigValue);
-                        int i = tmp.indexOf('\n');
+                        QString strTmp(m_strConfigValue);
+                        int i = strTmp.indexOf('\n');
                         if (i > -1)
-                            tmp.replace(i, tmp.length(), "...");
-                        v = tmp; break;
+                            strTmp.replace(i, strTmp.length(), "...");
+                        value = strTmp; break;
                     }
-                    case KVirtualSystemDescriptionType_OS:             v = vboxGlobal().vmGuestOSTypeDescription(m_strConfigValue); break;
-                    case KVirtualSystemDescriptionType_Memory:         v = m_strConfigValue + " " + VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes"); break;
-                    case KVirtualSystemDescriptionType_SoundCard:      v = gpConverter->toString(static_cast<KAudioControllerType>(m_strConfigValue.toInt())); break;
-                    case KVirtualSystemDescriptionType_NetworkAdapter: v = gpConverter->toString(static_cast<KNetworkAdapterType>(m_strConfigValue.toInt())); break;
-                    default:                                           v = m_strConfigValue; break;
+                    case KVirtualSystemDescriptionType_OS:             value = vboxGlobal().vmGuestOSTypeDescription(m_strConfigValue); break;
+                    case KVirtualSystemDescriptionType_Memory:         value = m_strConfigValue + " " + VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes"); break;
+                    case KVirtualSystemDescriptionType_SoundCard:      value = gpConverter->toString(static_cast<KAudioControllerType>(m_strConfigValue.toInt())); break;
+                    case KVirtualSystemDescriptionType_NetworkAdapter: value = gpConverter->toString(static_cast<KNetworkAdapterType>(m_strConfigValue.toInt())); break;
+                    default:                                           value = m_strConfigValue; break;
                 }
             }
@@ -451,8 +449,8 @@
         case Qt::ToolTipRole:
         {
-            if (column == ApplianceViewSection_ConfigValue)
+            if (iColumn == ApplianceViewSection_ConfigValue)
             {
                 if (!m_strOrigValue.isEmpty())
-                    v = UIApplianceEditorWidget::tr("<b>Original Value:</b> %1").arg(m_strOrigValue);
+                    value = UIApplianceEditorWidget::tr("<b>Original Value:</b> %1").arg(m_strOrigValue);
             }
             break;
@@ -460,9 +458,9 @@
         case Qt::DecorationRole:
         {
-            if (column == ApplianceViewSection_Description)
-            {
-                switch (m_type)
+            if (iColumn == ApplianceViewSection_Description)
+            {
+                switch (m_enmType)
                 {
-                    case KVirtualSystemDescriptionType_Name:                   v = UIIconPool::iconSet(":/name_16px.png"); break;
+                    case KVirtualSystemDescriptionType_Name:                   value = UIIconPool::iconSet(":/name_16px.png"); break;
                     case KVirtualSystemDescriptionType_Product:
                     case KVirtualSystemDescriptionType_ProductUrl:
@@ -471,27 +469,27 @@
                     case KVirtualSystemDescriptionType_Version:
                     case KVirtualSystemDescriptionType_Description:
-                    case KVirtualSystemDescriptionType_License:                v = UIIconPool::iconSet(":/description_16px.png"); break;
-                    case KVirtualSystemDescriptionType_OS:                     v = UIIconPool::iconSet(":/os_type_16px.png"); break;
-                    case KVirtualSystemDescriptionType_CPU:                    v = UIIconPool::iconSet(":/cpu_16px.png"); break;
-                    case KVirtualSystemDescriptionType_Memory:                 v = UIIconPool::iconSet(":/ram_16px.png"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerIDE:  v = UIIconPool::iconSet(":/ide_16px.png"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerSATA: v = UIIconPool::iconSet(":/sata_16px.png"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerSCSI: v = UIIconPool::iconSet(":/scsi_16px.png"); break;
-                    case KVirtualSystemDescriptionType_HardDiskControllerSAS:  v = UIIconPool::iconSet(":/scsi_16px.png"); break;
-                    case KVirtualSystemDescriptionType_HardDiskImage:          v = UIIconPool::iconSet(":/hd_16px.png"); break;
-                    case KVirtualSystemDescriptionType_CDROM:                  v = UIIconPool::iconSet(":/cd_16px.png"); break;
-                    case KVirtualSystemDescriptionType_Floppy:                 v = UIIconPool::iconSet(":/fd_16px.png"); break;
-                    case KVirtualSystemDescriptionType_NetworkAdapter:         v = UIIconPool::iconSet(":/nw_16px.png"); break;
-                    case KVirtualSystemDescriptionType_USBController:          v = UIIconPool::iconSet(":/usb_16px.png"); break;
-                    case KVirtualSystemDescriptionType_SoundCard:              v = UIIconPool::iconSet(":/sound_16px.png"); break;
+                    case KVirtualSystemDescriptionType_License:                value = UIIconPool::iconSet(":/description_16px.png"); break;
+                    case KVirtualSystemDescriptionType_OS:                     value = UIIconPool::iconSet(":/os_type_16px.png"); break;
+                    case KVirtualSystemDescriptionType_CPU:                    value = UIIconPool::iconSet(":/cpu_16px.png"); break;
+                    case KVirtualSystemDescriptionType_Memory:                 value = UIIconPool::iconSet(":/ram_16px.png"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerIDE:  value = UIIconPool::iconSet(":/ide_16px.png"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerSATA: value = UIIconPool::iconSet(":/sata_16px.png"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerSCSI: value = UIIconPool::iconSet(":/scsi_16px.png"); break;
+                    case KVirtualSystemDescriptionType_HardDiskControllerSAS:  value = UIIconPool::iconSet(":/scsi_16px.png"); break;
+                    case KVirtualSystemDescriptionType_HardDiskImage:          value = UIIconPool::iconSet(":/hd_16px.png"); break;
+                    case KVirtualSystemDescriptionType_CDROM:                  value = UIIconPool::iconSet(":/cd_16px.png"); break;
+                    case KVirtualSystemDescriptionType_Floppy:                 value = UIIconPool::iconSet(":/fd_16px.png"); break;
+                    case KVirtualSystemDescriptionType_NetworkAdapter:         value = UIIconPool::iconSet(":/nw_16px.png"); break;
+                    case KVirtualSystemDescriptionType_USBController:          value = UIIconPool::iconSet(":/usb_16px.png"); break;
+                    case KVirtualSystemDescriptionType_SoundCard:              value = UIIconPool::iconSet(":/sound_16px.png"); break;
                     default: break;
                 }
             }
-            else if (column == ApplianceViewSection_ConfigValue &&
-                     m_type == KVirtualSystemDescriptionType_OS)
+            else if (iColumn == ApplianceViewSection_ConfigValue &&
+                     m_enmType == KVirtualSystemDescriptionType_OS)
             {
                 const QStyle *pStyle = QApplication::style();
                 const int iIconMetric = pStyle->pixelMetric(QStyle::PM_SmallIconSize);
-                v = vboxGlobal().vmGuestOSTypeIcon(m_strConfigValue).scaledToHeight(iIconMetric, Qt::SmoothTransformation);
+                value = vboxGlobal().vmGuestOSTypeIcon(m_strConfigValue).scaledToHeight(iIconMetric, Qt::SmoothTransformation);
             }
             break;
@@ -500,10 +498,10 @@
         {
             /* If the item is unchecked mark it with italic text. */
-            if (column == ApplianceViewSection_ConfigValue &&
+            if (iColumn == ApplianceViewSection_ConfigValue &&
                 m_checkState == Qt::Unchecked)
             {
                 QFont font = qApp->font();
                 font.setItalic(true);
-                v = font;
+                value = font;
             }
             break;
@@ -512,9 +510,9 @@
         {
             /* If the item is unchecked mark it with gray text. */
-            if (column == ApplianceViewSection_ConfigValue &&
+            if (iColumn == ApplianceViewSection_ConfigValue &&
                 m_checkState == Qt::Unchecked)
             {
                 QPalette pal = qApp->palette();
-                v = pal.brush(QPalette::Disabled, QPalette::WindowText);
+                value = pal.brush(QPalette::Disabled, QPalette::WindowText);
             }
             break;
@@ -522,38 +520,38 @@
         case Qt::CheckStateRole:
         {
-            if (column == ApplianceViewSection_ConfigValue &&
-                (m_type == KVirtualSystemDescriptionType_Floppy ||
-                 m_type == KVirtualSystemDescriptionType_CDROM ||
-                 m_type == KVirtualSystemDescriptionType_USBController ||
-                 m_type == KVirtualSystemDescriptionType_SoundCard ||
-                 m_type == KVirtualSystemDescriptionType_NetworkAdapter))
-                v = m_checkState;
+            if (iColumn == ApplianceViewSection_ConfigValue &&
+                (m_enmType == KVirtualSystemDescriptionType_Floppy ||
+                 m_enmType == KVirtualSystemDescriptionType_CDROM ||
+                 m_enmType == KVirtualSystemDescriptionType_USBController ||
+                 m_enmType == KVirtualSystemDescriptionType_SoundCard ||
+                 m_enmType == KVirtualSystemDescriptionType_NetworkAdapter))
+                value = m_checkState;
             break;
         }
         case HardwareItem::TypeRole:
         {
-            v = m_type;
+            value = m_enmType;
             break;
         }
         case HardwareItem::ModifiedRole:
         {
-            if (column == ApplianceViewSection_ConfigValue)
-                v = m_fModified;
+            if (iColumn == ApplianceViewSection_ConfigValue)
+                value = m_fModified;
             break;
         }
     }
-    return v;
+    return value;
 }
 
 QWidget *HardwareItem::createEditor(QWidget *pParent, const QStyleOptionViewItem & /* styleOption */, const QModelIndex &idx) const
 {
-    QWidget *editor = NULL;
+    QWidget *pEditor = 0;
     if (idx.column() == ApplianceViewSection_ConfigValue)
     {
-        switch (m_type)
+        switch (m_enmType)
         {
             case KVirtualSystemDescriptionType_OS:
             {
-                VBoxOSTypeSelectorButton *e = new VBoxOSTypeSelectorButton(pParent);
+                VBoxOSTypeSelectorButton *pButton = new VBoxOSTypeSelectorButton(pParent);
                 /* Fill the background with the highlight color in the case
                  * the button hasn't a rectangle shape. This prevents the
@@ -562,11 +560,11 @@
                 /* Use the palette from the tree view, not the one from the
                  * editor. */
-                QPalette p = e->palette();
+                QPalette p = pButton->palette();
                 p.setBrush(QPalette::Highlight, pParent->palette().brush(QPalette::Highlight));
-                e->setPalette(p);
+                pButton->setPalette(p);
 #endif /* VBOX_WS_MAC */
-                e->setAutoFillBackground(true);
-                e->setBackgroundRole(QPalette::Highlight);
-                editor = e;
+                pButton->setAutoFillBackground(true);
+                pButton->setBackgroundRole(QPalette::Highlight);
+                pEditor = pButton;
                 break;
             }
@@ -578,6 +576,6 @@
             case KVirtualSystemDescriptionType_Version:
             {
-                QLineEdit *e = new QLineEdit(pParent);
-                editor = e;
+                QLineEdit *pLineEdit = new QLineEdit(pParent);
+                pEditor = pLineEdit;
                 break;
             }
@@ -585,55 +583,55 @@
             case KVirtualSystemDescriptionType_License:
             {
-                UILineTextEdit *e = new UILineTextEdit(pParent);
-                editor = e;
+                UILineTextEdit *pLineTextEdit = new UILineTextEdit(pParent);
+                pEditor = pLineTextEdit;
                 break;
             }
             case KVirtualSystemDescriptionType_CPU:
             {
-                QSpinBox *e = new QSpinBox(pParent);
-                e->setRange(UIApplianceEditorWidget::minGuestCPUCount(), UIApplianceEditorWidget::maxGuestCPUCount());
-                editor = e;
+                QSpinBox *pSpinBox = new QSpinBox(pParent);
+                pSpinBox->setRange(UIApplianceEditorWidget::minGuestCPUCount(), UIApplianceEditorWidget::maxGuestCPUCount());
+                pEditor = pSpinBox;
                 break;
             }
             case KVirtualSystemDescriptionType_Memory:
             {
-                QSpinBox *e = new QSpinBox(pParent);
-                e->setRange(UIApplianceEditorWidget::minGuestRAM(), UIApplianceEditorWidget::maxGuestRAM());
-                e->setSuffix(" " + VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes"));
-                editor = e;
+                QSpinBox *pSpinBox = new QSpinBox(pParent);
+                pSpinBox->setRange(UIApplianceEditorWidget::minGuestRAM(), UIApplianceEditorWidget::maxGuestRAM());
+                pSpinBox->setSuffix(" " + VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes"));
+                pEditor = pSpinBox;
                 break;
             }
             case KVirtualSystemDescriptionType_SoundCard:
             {
-                QComboBox *e = new QComboBox(pParent);
-                e->addItem(gpConverter->toString(KAudioControllerType_AC97), KAudioControllerType_AC97);
-                e->addItem(gpConverter->toString(KAudioControllerType_SB16), KAudioControllerType_SB16);
-                e->addItem(gpConverter->toString(KAudioControllerType_HDA),  KAudioControllerType_HDA);
-                editor = e;
+                QComboBox *pComboBox = new QComboBox(pParent);
+                pComboBox->addItem(gpConverter->toString(KAudioControllerType_AC97), KAudioControllerType_AC97);
+                pComboBox->addItem(gpConverter->toString(KAudioControllerType_SB16), KAudioControllerType_SB16);
+                pComboBox->addItem(gpConverter->toString(KAudioControllerType_HDA),  KAudioControllerType_HDA);
+                pEditor = pComboBox;
                 break;
             }
             case KVirtualSystemDescriptionType_NetworkAdapter:
             {
-                QComboBox *e = new QComboBox(pParent);
-                e->addItem(gpConverter->toString(KNetworkAdapterType_Am79C970A), KNetworkAdapterType_Am79C970A);
-                e->addItem(gpConverter->toString(KNetworkAdapterType_Am79C973), KNetworkAdapterType_Am79C973);
+                QComboBox *pComboBox = new QComboBox(pParent);
+                pComboBox->addItem(gpConverter->toString(KNetworkAdapterType_Am79C970A), KNetworkAdapterType_Am79C970A);
+                pComboBox->addItem(gpConverter->toString(KNetworkAdapterType_Am79C973), KNetworkAdapterType_Am79C973);
 #ifdef VBOX_WITH_E1000
-                e->addItem(gpConverter->toString(KNetworkAdapterType_I82540EM), KNetworkAdapterType_I82540EM);
-                e->addItem(gpConverter->toString(KNetworkAdapterType_I82543GC), KNetworkAdapterType_I82543GC);
-                e->addItem(gpConverter->toString(KNetworkAdapterType_I82545EM), KNetworkAdapterType_I82545EM);
+                pComboBox->addItem(gpConverter->toString(KNetworkAdapterType_I82540EM), KNetworkAdapterType_I82540EM);
+                pComboBox->addItem(gpConverter->toString(KNetworkAdapterType_I82543GC), KNetworkAdapterType_I82543GC);
+                pComboBox->addItem(gpConverter->toString(KNetworkAdapterType_I82545EM), KNetworkAdapterType_I82545EM);
 #endif /* VBOX_WITH_E1000 */
 #ifdef VBOX_WITH_VIRTIO
-                e->addItem(gpConverter->toString(KNetworkAdapterType_Virtio), KNetworkAdapterType_Virtio);
+                pComboBox->addItem(gpConverter->toString(KNetworkAdapterType_Virtio), KNetworkAdapterType_Virtio);
 #endif /* VBOX_WITH_VIRTIO */
-                editor = e;
+                pEditor = pComboBox;
                 break;
             }
             case KVirtualSystemDescriptionType_HardDiskControllerIDE:
             {
-                QComboBox *e = new QComboBox(pParent);
-                e->addItem(gpConverter->toString(KStorageControllerType_PIIX3), "PIIX3");
-                e->addItem(gpConverter->toString(KStorageControllerType_PIIX4), "PIIX4");
-                e->addItem(gpConverter->toString(KStorageControllerType_ICH6),  "ICH6");
-                editor = e;
+                QComboBox *pComboBox = new QComboBox(pParent);
+                pComboBox->addItem(gpConverter->toString(KStorageControllerType_PIIX3), "PIIX3");
+                pComboBox->addItem(gpConverter->toString(KStorageControllerType_PIIX4), "PIIX4");
+                pComboBox->addItem(gpConverter->toString(KStorageControllerType_ICH6),  "ICH6");
+                pEditor = pComboBox;
                 break;
             }
@@ -641,10 +639,10 @@
             {
                 /* disabled for now
-                   UIFilePathSelector *e = new UIFilePathSelector(pParent);
-                   e->setMode(UIFilePathSelector::Mode_File);
-                   e->setResetEnabled(false);
+                   UIFilePathSelector *pFileChooser = new UIFilePathSelector(pParent);
+                   pFileChooser->setMode(UIFilePathSelector::Mode_File);
+                   pFileChooser->setResetEnabled(false);
                    */
-                QLineEdit *e = new QLineEdit(pParent);
-                editor = e;
+                QLineEdit *pLineEdit = new QLineEdit(pParent);
+                pEditor = pLineEdit;
                 break;
             }
@@ -652,5 +650,5 @@
         }
     }
-    return editor;
+    return pEditor;
 }
 
@@ -658,11 +656,11 @@
 {
     bool fDone = false;
-    switch (m_type)
+    switch (m_enmType)
     {
         case KVirtualSystemDescriptionType_OS:
         {
-            if (VBoxOSTypeSelectorButton *e = qobject_cast<VBoxOSTypeSelectorButton*>(pEditor))
-            {
-                e->setOSTypeId(m_strConfigValue);
+            if (VBoxOSTypeSelectorButton *pButton = qobject_cast<VBoxOSTypeSelectorButton*>(pEditor))
+            {
+                pButton->setOSTypeId(m_strConfigValue);
                 fDone = true;
             }
@@ -671,9 +669,9 @@
         case KVirtualSystemDescriptionType_HardDiskControllerIDE:
         {
-            if (QComboBox *e = qobject_cast<QComboBox*>(pEditor))
-            {
-                int i = e->findData(m_strConfigValue);
+            if (QComboBox *pComboBox = qobject_cast<QComboBox*>(pEditor))
+            {
+                int i = pComboBox->findData(m_strConfigValue);
                 if (i != -1)
-                    e->setCurrentIndex(i);
+                    pComboBox->setCurrentIndex(i);
                 fDone = true;
             }
@@ -683,7 +681,7 @@
         case KVirtualSystemDescriptionType_Memory:
         {
-            if (QSpinBox *e = qobject_cast<QSpinBox*>(pEditor))
-            {
-                e->setValue(m_strConfigValue.toInt());
+            if (QSpinBox *pSpinBox = qobject_cast<QSpinBox*>(pEditor))
+            {
+                pSpinBox->setValue(m_strConfigValue.toInt());
                 fDone = true;
             }
@@ -697,7 +695,7 @@
         case KVirtualSystemDescriptionType_Version:
         {
-            if (QLineEdit *e = qobject_cast<QLineEdit*>(pEditor))
-            {
-                e->setText(m_strConfigValue);
+            if (QLineEdit *pLineEdit = qobject_cast<QLineEdit*>(pEditor))
+            {
+                pLineEdit->setText(m_strConfigValue);
                 fDone = true;
             }
@@ -707,7 +705,7 @@
         case KVirtualSystemDescriptionType_License:
         {
-            if (UILineTextEdit *e = qobject_cast<UILineTextEdit*>(pEditor))
-            {
-                e->setText(m_strConfigValue);
+            if (UILineTextEdit *pLineTextEdit = qobject_cast<UILineTextEdit*>(pEditor))
+            {
+                pLineTextEdit->setText(m_strConfigValue);
                 fDone = true;
             }
@@ -717,9 +715,9 @@
         case KVirtualSystemDescriptionType_NetworkAdapter:
         {
-            if (QComboBox *e = qobject_cast<QComboBox*>(pEditor))
-            {
-                int i = e->findData(m_strConfigValue.toInt());
+            if (QComboBox *pComboBox = qobject_cast<QComboBox*>(pEditor))
+            {
+                int i = pComboBox->findData(m_strConfigValue.toInt());
                 if (i != -1)
-                    e->setCurrentIndex(i);
+                    pComboBox->setCurrentIndex(i);
                 fDone = true;
             }
@@ -729,12 +727,12 @@
         {
             /* disabled for now
-               if (UIFilePathSelector *e = qobject_cast<UIFilePathSelector*>(pEditor))
+               if (UIFilePathSelector *pFileChooser = qobject_cast<UIFilePathSelector*>(pEditor))
                {
-               e->setPath(m_strConfigValue);
+               pFileChooser->setPath(m_strConfigValue);
                }
                */
-            if (QLineEdit *e = qobject_cast<QLineEdit*>(pEditor))
-            {
-                e->setText(m_strConfigValue);
+            if (QLineEdit *pLineEdit = qobject_cast<QLineEdit*>(pEditor))
+            {
+                pLineEdit->setText(m_strConfigValue);
                 fDone = true;
             }
@@ -749,11 +747,11 @@
 {
     bool fDone = false;
-    switch (m_type)
+    switch (m_enmType)
     {
         case KVirtualSystemDescriptionType_OS:
         {
-            if (VBoxOSTypeSelectorButton *e = qobject_cast<VBoxOSTypeSelectorButton*>(pEditor))
-            {
-                m_strConfigValue = e->osTypeId();
+            if (VBoxOSTypeSelectorButton *pButton = qobject_cast<VBoxOSTypeSelectorButton*>(pEditor))
+            {
+                m_strConfigValue = pButton->osTypeId();
                 fDone = true;
             }
@@ -762,7 +760,7 @@
         case KVirtualSystemDescriptionType_HardDiskControllerIDE:
         {
-            if (QComboBox *e = qobject_cast<QComboBox*>(pEditor))
-            {
-                m_strConfigValue = e->itemData(e->currentIndex()).toString();
+            if (QComboBox *pComboBox = qobject_cast<QComboBox*>(pEditor))
+            {
+                m_strConfigValue = pComboBox->itemData(pComboBox->currentIndex()).toString();
                 fDone = true;
             }
@@ -772,7 +770,7 @@
         case KVirtualSystemDescriptionType_Memory:
         {
-            if (QSpinBox *e = qobject_cast<QSpinBox*>(pEditor))
-            {
-                m_strConfigValue = QString::number(e->value());
+            if (QSpinBox *pSpinBox = qobject_cast<QSpinBox*>(pEditor))
+            {
+                m_strConfigValue = QString::number(pSpinBox->value());
                 fDone = true;
             }
@@ -781,5 +779,5 @@
         case KVirtualSystemDescriptionType_Name:
         {
-            if (QLineEdit *e = qobject_cast<QLineEdit*>(pEditor))
+            if (QLineEdit *pLineEdit = qobject_cast<QLineEdit*>(pEditor))
             {
                 /* When the VM name is changed the path of the disk images
@@ -811,5 +809,5 @@
                         foreach (QString a, splittedOriginalPath)
                         {
-                            (a.compare(m_strConfigValue) == 0) ? splittedNewPath << e->text() : splittedNewPath << a;
+                            (a.compare(m_strConfigValue) == 0) ? splittedNewPath << pLineEdit->text() : splittedNewPath << a;
                         }
 
@@ -821,5 +819,5 @@
                     }
                 }
-                m_strConfigValue = e->text();
+                m_strConfigValue = pLineEdit->text();
                 fDone = true;
             }
@@ -832,7 +830,7 @@
         case KVirtualSystemDescriptionType_Version:
         {
-            if (QLineEdit *e = qobject_cast<QLineEdit*>(pEditor))
-            {
-                m_strConfigValue = e->text();
+            if (QLineEdit *pLineEdit = qobject_cast<QLineEdit*>(pEditor))
+            {
+                m_strConfigValue = pLineEdit->text();
                 fDone = true;
             }
@@ -842,7 +840,7 @@
         case KVirtualSystemDescriptionType_License:
         {
-            if (UILineTextEdit *e = qobject_cast<UILineTextEdit*>(pEditor))
-            {
-                m_strConfigValue = e->text();
+            if (UILineTextEdit *pLineTextEdit = qobject_cast<UILineTextEdit*>(pEditor))
+            {
+                m_strConfigValue = pLineTextEdit->text();
                 fDone = true;
             }
@@ -852,7 +850,7 @@
         case KVirtualSystemDescriptionType_NetworkAdapter:
         {
-            if (QComboBox *e = qobject_cast<QComboBox*>(pEditor))
-            {
-                m_strConfigValue = e->itemData(e->currentIndex()).toString();
+            if (QComboBox *pComboBox = qobject_cast<QComboBox*>(pEditor))
+            {
+                m_strConfigValue = pComboBox->itemData(pComboBox->currentIndex()).toString();
                 fDone = true;
             }
@@ -862,12 +860,12 @@
         {
             /* disabled for now
-               if (UIFilePathSelector *e = qobject_cast<UIFilePathSelector*>(pEditor))
+               if (UIFilePathSelector *pFileChooser = qobject_cast<UIFilePathSelector*>(pEditor))
                {
-               m_strConfigValue = e->path();
+               m_strConfigValue = pFileChooser->path();
                }
                */
-            if (QLineEdit *e = qobject_cast<QLineEdit*>(pEditor))
-            {
-                m_strConfigValue = e->text();
+            if (QLineEdit *pLineEdit = qobject_cast<QLineEdit*>(pEditor))
+            {
+                m_strConfigValue = pLineEdit->text();
                 fDone = true;
             }
@@ -888,9 +886,9 @@
 }
 
-void HardwareItem::putBack(QVector<BOOL>& finalStates, QVector<QString>& finalValues, QVector<QString>& finalExtraValues)
-{
-    finalStates[m_number]      = m_checkState == Qt::Checked;
-    finalValues[m_number]      = m_strConfigValue;
-    finalExtraValues[m_number] = m_strExtraConfigValue;
+void HardwareItem::putBack(QVector<BOOL> &finalStates, QVector<QString> &finalValues, QVector<QString> &finalExtraValues)
+{
+    finalStates[m_iNumber] = m_checkState == Qt::Checked;
+    finalValues[m_iNumber] = m_strConfigValue;
+    finalExtraValues[m_iNumber] = m_strExtraConfigValue;
     ModelItem::putBack(finalStates, finalValues, finalExtraValues);
 }
@@ -901,17 +899,14 @@
 *********************************************************************************************************************************/
 
-/* This class is a wrapper model for our ModelItem. It could be used with any
-   TreeView & forward mostly all calls to the methods of ModelItem. The
-   ModelItems itself are stored as internal pointers in the QModelIndex class. */
-VirtualSystemModel::VirtualSystemModel(QVector<CVirtualSystemDescription>& aVSDs, QObject *pParent /* = NULL */)
-   : QAbstractItemModel(pParent)
+VirtualSystemModel::VirtualSystemModel(QVector<CVirtualSystemDescription>& aVSDs, QObject *pParent /* = 0 */)
+    : QAbstractItemModel(pParent)
 {
     m_pRootItem = new ModelItem(0, ApplianceModelItemType_Root);
-    for (int a = 0; a < aVSDs.size(); ++a)
+    for (int iVSDIndex = 0; iVSDIndex < aVSDs.size(); ++iVSDIndex)
     {
-        CVirtualSystemDescription vs = aVSDs[a];
-
-        VirtualSystemItem *vi = new VirtualSystemItem(a, vs, m_pRootItem);
-        m_pRootItem->appendChild(vi);
+        CVirtualSystemDescription vsd = aVSDs[iVSDIndex];
+
+        VirtualSystemItem *pVirtualSystemItem = new VirtualSystemItem(iVSDIndex, vsd, m_pRootItem);
+        m_pRootItem->appendChild(pVirtualSystemItem);
 
         /** @todo ask Dmitry about include/COMDefs.h:232 */
@@ -922,7 +917,7 @@
         QVector<QString> extraConfigValues;
 
-        QList<int> hdIndizies;
+        QList<int> hdIndexes;
         QMap<int, HardwareItem*> controllerMap;
-        vs.GetDescription(types, refs, origValues, configValues, extraConfigValues);
+        vsd.GetDescription(types, refs, origValues, configValues, extraConfigValues);
         for (int i = 0; i < types.size(); ++i)
         {
@@ -930,9 +925,9 @@
                reference to them. */
             if (types[i] == KVirtualSystemDescriptionType_HardDiskImage)
-                hdIndizies << i;
+                hdIndexes << i;
             else
             {
-                HardwareItem *hi = new HardwareItem(i, types[i], refs[i], origValues[i], configValues[i], extraConfigValues[i], vi);
-                vi->appendChild(hi);
+                HardwareItem *pHardwareItem = new HardwareItem(i, types[i], refs[i], origValues[i], configValues[i], extraConfigValues[i], pVirtualSystemItem);
+                pVirtualSystemItem->appendChild(pHardwareItem);
                 /* Save the hard disk controller types in an extra map */
                 if (types[i] == KVirtualSystemDescriptionType_HardDiskControllerIDE ||
@@ -940,22 +935,22 @@
                     types[i] == KVirtualSystemDescriptionType_HardDiskControllerSCSI ||
                     types[i] == KVirtualSystemDescriptionType_HardDiskControllerSAS)
-                    controllerMap[i] = hi;
+                    controllerMap[i] = pHardwareItem;
             }
         }
         QRegExp rx("controller=(\\d+);?");
         /* Now process the hard disk images */
-        for (int a = 0; a < hdIndizies.size(); ++a)
-        {
-            int i = hdIndizies[a];
+        for (int iHDIndex = 0; iHDIndex < hdIndexes.size(); ++iHDIndex)
+        {
+            int i = hdIndexes[iHDIndex];
             QString ecnf = extraConfigValues[i];
             if (rx.indexIn(ecnf) != -1)
             {
                 /* Get the controller */
-                HardwareItem *ci = controllerMap[rx.cap(1).toInt()];
-                if (ci)
+                HardwareItem *pControllerItem = controllerMap[rx.cap(1).toInt()];
+                if (pControllerItem)
                 {
                     /* New hardware item as child of the controller */
-                    HardwareItem *hi = new HardwareItem(i, types[i], refs[i], origValues[i], configValues[i], extraConfigValues[i], ci);
-                    ci->appendChild(hi);
+                    HardwareItem *pStorageItem = new HardwareItem(i, types[i], refs[i], origValues[i], configValues[i], extraConfigValues[i], pControllerItem);
+                    pControllerItem->appendChild(pStorageItem);
                 }
             }
@@ -970,19 +965,19 @@
 }
 
-QModelIndex VirtualSystemModel::index(int row, int column, const QModelIndex &parentIdx /* = QModelIndex() */) const
-{
-    if (!hasIndex(row, column, parentIdx))
+QModelIndex VirtualSystemModel::index(int iRow, int iColumn, const QModelIndex &parentIdx /* = QModelIndex() */) const
+{
+    if (!hasIndex(iRow, iColumn, parentIdx))
         return QModelIndex();
 
-    ModelItem *parentItem;
+    ModelItem *pParentItem;
 
     if (!parentIdx.isValid())
-        parentItem = m_pRootItem;
+        pParentItem = m_pRootItem;
     else
-        parentItem = static_cast<ModelItem*>(parentIdx.internalPointer());
-
-    ModelItem *childItem = parentItem->child(row);
-    if (childItem)
-        return createIndex(row, column, childItem);
+        pParentItem = static_cast<ModelItem*>(parentIdx.internalPointer());
+
+    ModelItem *pChildItem = pParentItem->child(iRow);
+    if (pChildItem)
+        return createIndex(iRow, iColumn, pChildItem);
     else
         return QModelIndex();
@@ -994,25 +989,25 @@
         return QModelIndex();
 
-    ModelItem *childItem = static_cast<ModelItem*>(idx.internalPointer());
-    ModelItem *parentItem = childItem->parent();
-
-    if (parentItem == m_pRootItem)
+    ModelItem *pChildItem = static_cast<ModelItem*>(idx.internalPointer());
+    ModelItem *pParentItem = pChildItem->parent();
+
+    if (pParentItem == m_pRootItem)
         return QModelIndex();
 
-    return createIndex(parentItem->row(), 0, parentItem);
+    return createIndex(pParentItem->row(), 0, pParentItem);
 }
 
 int VirtualSystemModel::rowCount(const QModelIndex &parentIdx /* = QModelIndex() */) const
 {
-    ModelItem *parentItem;
+    ModelItem *pParentItem;
     if (parentIdx.column() > 0)
         return 0;
 
     if (!parentIdx.isValid())
-        parentItem = m_pRootItem;
+        pParentItem = m_pRootItem;
     else
-        parentItem = static_cast<ModelItem*>(parentIdx.internalPointer());
-
-    return parentItem->childCount();
+        pParentItem = static_cast<ModelItem*>(parentIdx.internalPointer());
+
+    return pParentItem->childCount();
 }
 
@@ -1030,42 +1025,42 @@
         return 0;
 
-    ModelItem *item = static_cast<ModelItem*>(idx.internalPointer());
-
-    return Qt::ItemIsEnabled | Qt::ItemIsSelectable | item->itemFlags(idx.column());
-}
-
-QVariant VirtualSystemModel::headerData(int section, Qt::Orientation orientation, int role) const
-{
-    if (role != Qt::DisplayRole ||
-        orientation != Qt::Horizontal)
+    ModelItem *pItem = static_cast<ModelItem*>(idx.internalPointer());
+
+    return Qt::ItemIsEnabled | Qt::ItemIsSelectable | pItem->itemFlags(idx.column());
+}
+
+QVariant VirtualSystemModel::headerData(int iSection, Qt::Orientation enmOrientation, int iRole) const
+{
+    if (iRole != Qt::DisplayRole ||
+        enmOrientation != Qt::Horizontal)
         return QVariant();
 
-    QString title;
-    switch (section)
+    QString strTitle;
+    switch (iSection)
     {
-        case ApplianceViewSection_Description: title = UIApplianceEditorWidget::tr("Description"); break;
-        case ApplianceViewSection_ConfigValue: title = UIApplianceEditorWidget::tr("Configuration"); break;
+        case ApplianceViewSection_Description: strTitle = UIApplianceEditorWidget::tr("Description"); break;
+        case ApplianceViewSection_ConfigValue: strTitle = UIApplianceEditorWidget::tr("Configuration"); break;
     }
-    return title;
-}
-
-bool VirtualSystemModel::setData(const QModelIndex &idx, const QVariant &value, int role)
+    return strTitle;
+}
+
+bool VirtualSystemModel::setData(const QModelIndex &idx, const QVariant &value, int iRole)
 {
     if (!idx.isValid())
         return false;
 
-    ModelItem *item = static_cast<ModelItem*>(idx.internalPointer());
-
-    return item->setData(idx.column(), value, role);
-}
-
-QVariant VirtualSystemModel::data(const QModelIndex &idx, int role /* = Qt::DisplayRole */) const
+    ModelItem *pTtem = static_cast<ModelItem*>(idx.internalPointer());
+
+    return pTtem->setData(idx.column(), value, iRole);
+}
+
+QVariant VirtualSystemModel::data(const QModelIndex &idx, int iRole /* = Qt::DisplayRole */) const
 {
     if (!idx.isValid())
         return QVariant();
 
-    ModelItem *item = static_cast<ModelItem*>(idx.internalPointer());
-
-    return item->data(idx.column(), role);
+    ModelItem *pTtem = static_cast<ModelItem*>(idx.internalPointer());
+
+    return pTtem->data(idx.column(), iRole);
 }
 
@@ -1083,17 +1078,17 @@
 void VirtualSystemModel::restoreDefaults(const QModelIndex &parentIdx /* = QModelIndex() */)
 {
-    ModelItem *parentItem;
+    ModelItem *pParentItem;
 
     if (!parentIdx.isValid())
-        parentItem = m_pRootItem;
+        pParentItem = m_pRootItem;
     else
-        parentItem = static_cast<ModelItem*>(parentIdx.internalPointer());
-
-    for (int i = 0; i < parentItem->childCount(); ++i)
+        pParentItem = static_cast<ModelItem*>(parentIdx.internalPointer());
+
+    for (int i = 0; i < pParentItem->childCount(); ++i)
     {
-        parentItem->child(i)->restoreDefaults();
+        pParentItem->child(i)->restoreDefaults();
         restoreDefaults(index(i, 0, parentIdx));
     }
-    emit dataChanged(index(0, 0, parentIdx), index(parentItem->childCount()-1, 0, parentIdx));
+    emit dataChanged(index(0, 0, parentIdx), index(pParentItem->childCount()-1, 0, parentIdx));
 }
 
@@ -1111,14 +1106,9 @@
 *********************************************************************************************************************************/
 
-/* The delegate is used for creating/handling the different editors for the
-   various types we support. This class forward the requests to the virtual
-   methods of our different ModelItems. If this is not possible the default
-   methods of QItemDelegate are used to get some standard behavior. Note: We
-   have to handle the proxy model ourself. I really don't understand why Qt is
-   not doing this for us. */
-VirtualSystemDelegate::VirtualSystemDelegate(QAbstractProxyModel *pProxy, QObject *pParent /* = NULL */)
-  : QItemDelegate(pParent)
-  , mProxy(pProxy)
-{}
+VirtualSystemDelegate::VirtualSystemDelegate(QAbstractProxyModel *pProxy, QObject *pParent /* = 0 */)
+    : QItemDelegate(pParent)
+    , m_pProxy(pProxy)
+{
+}
 
 QWidget *VirtualSystemDelegate::createEditor(QWidget *pParent, const QStyleOptionViewItem &styleOption, const QModelIndex &idx) const
@@ -1128,18 +1118,18 @@
 
     QModelIndex index(idx);
-    if (mProxy)
-        index = mProxy->mapToSource(idx);
-
-    ModelItem *item = static_cast<ModelItem*>(index.internalPointer());
-    QWidget *editor = item->createEditor(pParent, styleOption, index);
+    if (m_pProxy)
+        index = m_pProxy->mapToSource(idx);
+
+    ModelItem *pItem = static_cast<ModelItem*>(index.internalPointer());
+    QWidget *pEditor = pItem->createEditor(pParent, styleOption, index);
 
     /* Allow UILineTextEdit to commit data early: */
-    if (editor && qobject_cast<UILineTextEdit*>(editor))
-        connect(editor, SIGNAL(sigFinished(QWidget*)), this, SIGNAL(commitData(QWidget*)));
-
-    if (editor == NULL)
+    if (pEditor && qobject_cast<UILineTextEdit*>(pEditor))
+        connect(pEditor, SIGNAL(sigFinished(QWidget*)), this, SIGNAL(commitData(QWidget*)));
+
+    if (pEditor == 0)
         return QItemDelegate::createEditor(pParent, styleOption, index);
     else
-        return editor;
+        return pEditor;
 }
 
@@ -1150,10 +1140,10 @@
 
     QModelIndex index(idx);
-    if (mProxy)
-        index = mProxy->mapToSource(idx);
-
-    ModelItem *item = static_cast<ModelItem*>(index.internalPointer());
-
-    if (!item->setEditorData(pEditor, index))
+    if (m_pProxy)
+        index = m_pProxy->mapToSource(idx);
+
+    ModelItem *pItem = static_cast<ModelItem*>(index.internalPointer());
+
+    if (!pItem->setEditorData(pEditor, index))
         QItemDelegate::setEditorData(pEditor, index);
 }
@@ -1165,9 +1155,9 @@
 
     QModelIndex index = pModel->index(idx.row(), idx.column());
-    if (mProxy)
-        index = mProxy->mapToSource(idx);
-
-    ModelItem *item = static_cast<ModelItem*>(index.internalPointer());
-    if (!item->setModelData(pEditor, pModel, idx))
+    if (m_pProxy)
+        index = m_pProxy->mapToSource(idx);
+
+    ModelItem *pItem = static_cast<ModelItem*>(index.internalPointer());
+    if (!pItem->setModelData(pEditor, pModel, idx))
         QItemDelegate::setModelData(pEditor, pModel, idx);
 }
@@ -1218,5 +1208,5 @@
 
 /* static */
-KVirtualSystemDescriptionType VirtualSystemSortProxyModel::m_sortList[] =
+KVirtualSystemDescriptionType VirtualSystemSortProxyModel::s_aSortList[] =
 {
     KVirtualSystemDescriptionType_Name,
@@ -1244,21 +1234,22 @@
 VirtualSystemSortProxyModel::VirtualSystemSortProxyModel(QObject *pParent)
     : QSortFilterProxyModel(pParent)
-{}
-
-bool VirtualSystemSortProxyModel::filterAcceptsRow(int srcRow, const QModelIndex & srcParenIdx) const
+{
+}
+
+bool VirtualSystemSortProxyModel::filterAcceptsRow(int iSourceRow, const QModelIndex &srcParenIdx) const
 {
     /* By default enable all, we will explicitly filter out below */
     if (srcParenIdx.isValid())
     {
-        QModelIndex i = srcParenIdx.child(srcRow, 0);
+        QModelIndex i = srcParenIdx.child(iSourceRow, 0);
         if (i.isValid())
         {
-            ModelItem *item = static_cast<ModelItem*>(i.internalPointer());
+            ModelItem *pItem = static_cast<ModelItem*>(i.internalPointer());
             /* We filter hardware types only */
-            if (item->type() == ApplianceModelItemType_Hardware)
-            {
-                HardwareItem *hwItem = static_cast<HardwareItem*>(item);
+            if (pItem->type() == ApplianceModelItemType_Hardware)
+            {
+                HardwareItem *hwItem = static_cast<HardwareItem*>(pItem);
                 /* The license type shouldn't be displayed */
-                if (m_filterList.contains(hwItem->m_type))
+                if (m_aFilteredList.contains(hwItem->m_enmType))
                     return false;
             }
@@ -1285,9 +1276,9 @@
     HardwareItem *pHwRight = static_cast<HardwareItem*>(pRightItem);
 
-    for (unsigned int i = 0; i < RT_ELEMENTS(m_sortList); ++i)
-        if (pHwLeft->m_type == m_sortList[i])
+    for (unsigned int i = 0; i < RT_ELEMENTS(s_aSortList); ++i)
+        if (pHwLeft->m_enmType == s_aSortList[i])
         {
             for (unsigned int a = 0; a <= i; ++a)
-                if (pHwRight->m_type == m_sortList[a])
+                if (pHwRight->m_enmType == s_aSortList[a])
                     return true;
             return false;
@@ -1308,8 +1299,8 @@
 int UIApplianceEditorWidget::m_maxGuestCPUCount = -1;
 
-UIApplianceEditorWidget::UIApplianceEditorWidget(QWidget *pParent /* = NULL */)
+UIApplianceEditorWidget::UIApplianceEditorWidget(QWidget *pParent /* = 0 */)
     : QIWithRetranslateUI<QWidget>(pParent)
-    , m_pAppliance(NULL)
-    , m_pModel(NULL)
+    , m_pAppliance(0)
+    , m_pModel(0)
 {
     /* Make sure all static content is properly initialized */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceExportEditorWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceExportEditorWidget.cpp	(revision 64690)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceExportEditorWidget.cpp	(revision 64691)
@@ -44,5 +44,5 @@
       : VirtualSystemSortProxyModel(pParent)
     {
-        m_filterList
+        m_aFilteredList
             << KVirtualSystemDescriptionType_OS
             << KVirtualSystemDescriptionType_CPU
Index: /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceImportEditorWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceImportEditorWidget.cpp	(revision 64690)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceImportEditorWidget.cpp	(revision 64691)
@@ -45,5 +45,5 @@
       : VirtualSystemSortProxyModel(pParent)
     {
-        m_filterList << KVirtualSystemDescriptionType_License;
+        m_aFilteredList << KVirtualSystemDescriptionType_License;
     }
 };

Index: /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.h	(revision 64690)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.h	(revision 64691)
@@ -65,10 +65,10 @@
     /** Constructs the Virtual System model passing @a pParent to the base-class.
       * @param  aVSDs  Brings the Virtual System descriptions. */
-    VirtualSystemModel(QVector<CVirtualSystemDescription>& aVSDs, QObject *pParent = NULL);
+    VirtualSystemModel(QVector<CVirtualSystemDescription>& aVSDs, QObject *pParent = 0);
     /** Destructs the Virtual System model. */
     ~VirtualSystemModel();
 
-    /** Returns the index of the item in the model specified by the given @a row, @a column and @a parentIdx. */
-    QModelIndex index(int row, int column, const QModelIndex &parentIdx = QModelIndex()) const;
+    /** Returns the index of the item in the model specified by the given @a iRow, @a iColumn and @a parentIdx. */
+    QModelIndex index(int iRow, int iColumn, const QModelIndex &parentIdx = QModelIndex()) const;
     /** Returns the parent of the model item with the given @a idx. */
     QModelIndex parent(const QModelIndex &idx) const;
@@ -81,11 +81,11 @@
     /** Returns the item flags for the given @a idx. */
     Qt::ItemFlags flags(const QModelIndex &idx) const;
-    /** Returns the data for the given @a role and @a section in the header with the specified @a orientation. */
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-
-    /** Defines the @a role data for the item at @a idx to @a value. */
-    bool setData(const QModelIndex &idx, const QVariant &value, int role);
-    /** Returns the data stored under the given @a role for the item referred to by the @a idx. */
-    QVariant data(const QModelIndex &idx, int role = Qt::DisplayRole) const;
+    /** Returns the data for the given @a iRole and @a iSection in the header with the specified @a enmOrientation. */
+    QVariant headerData(int iSection, Qt::Orientation enmOrientation, int iRole) const;
+
+    /** Defines the @a iRole data for the item at @a idx to @a value. */
+    bool setData(const QModelIndex &idx, const QVariant &value, int iRole);
+    /** Returns the data stored under the given @a iRole for the item referred to by the @a idx. */
+    QVariant data(const QModelIndex &idx, int iRole = Qt::DisplayRole) const;
 
     /** Returns a model index for the buddy of the item represented by @a idx. */
@@ -112,5 +112,5 @@
     /** Constructs the Virtual System Delegate passing @a pParent to the base-class.
       * @param  pProxy  Brings the proxy model reference used to redirect requests to. */
-    VirtualSystemDelegate(QAbstractProxyModel *pProxy, QObject *pParent = NULL);
+    VirtualSystemDelegate(QAbstractProxyModel *pProxy, QObject *pParent = 0);
 
     /** Returns the widget used to edit the item specified by @a idx for editing.
@@ -140,5 +140,5 @@
 
     /** Holds the proxy model reference used to redirect requests to. */
-    QAbstractProxyModel *mProxy;
+    QAbstractProxyModel *m_pProxy;
 };
 
@@ -150,10 +150,10 @@
 
     /** Constructs the Virtual System Sorting model passing @a pParent to the base-class. */
-    VirtualSystemSortProxyModel(QObject *pParent = NULL);
+    VirtualSystemSortProxyModel(QObject *pParent = 0);
 
 protected:
 
-    /** Returns whether item in the row indicated by the given @a srcRow and @a srcParenIdx should be included in the model. */
-    bool filterAcceptsRow(int srcRow, const QModelIndex & srcParenIdx) const;
+    /** Returns whether item in the row indicated by the given @a iSourceRow and @a srcParenIdx should be included in the model. */
+    bool filterAcceptsRow(int iSourceRow, const QModelIndex &srcParenIdx) const;
 
     /** Returns whether value of the item referred to by the given index @a leftIdx is less
@@ -162,8 +162,8 @@
 
     /** Holds the array of sorted Virtual System Description types. */
-    static KVirtualSystemDescriptionType m_sortList[];
+    static KVirtualSystemDescriptionType s_aSortList[];
 
     /** Holds the filtered list of Virtual System Description types. */
-    QList<KVirtualSystemDescriptionType> m_filterList;
+    QList<KVirtualSystemDescriptionType> m_aFilteredList;
 };
 
@@ -177,10 +177,10 @@
 
     /** Constructs the Appliance Editor widget passing @a pParent to the base-class. */
-    UIApplianceEditorWidget(QWidget *pParent = NULL);
+    UIApplianceEditorWidget(QWidget *pParent = 0);
 
     /** Returns whether the Appliance Editor has valid state. */
-    bool isValid() const { return m_pAppliance != NULL; }
+    bool isValid() const { return m_pAppliance != 0; }
     /** Returns the currently set appliance reference. */
-    CAppliance* appliance() const { return m_pAppliance; }
+    CAppliance *appliance() const { return m_pAppliance; }
 
     /** Returns the minimum guest RAM. */
@@ -209,5 +209,5 @@
 
     /** Holds the information pane instance. */
-    QWidget *m_pPaneInformation;
+    QWidget   *m_pPaneInformation;
     /** Holds the settings tree-view instance. */
     QTreeView *m_pTreeViewSettings;
@@ -216,7 +216,7 @@
 
     /** Holds the warning pane instance. */
-    QWidget *m_pPaneWarning;
+    QWidget   *m_pPaneWarning;
     /** Holds the warning label instance. */
-    QLabel *m_pLabelWarning;
+    QLabel    *m_pLabelWarning;
     /** Holds the warning browser instance. */
     QTextEdit *m_pTextEditWarning;